@@ -38,12 +38,14 @@
 
 #include "gedit-commands.h"
 #include "gedit-window.h"
+#include "gedit-window-private.h"
 #include "gedit-notebook.h"
+#include "gedit-multi-notebook.h"
 #include "gedit-debug.h"
 
 void
 _gedit_cmd_documents_previous_document (GtkAction   *action,
-				       GeditWindow *window)
+					GeditWindow *window)
 {
 	GtkNotebook *notebook;
 
@@ -55,7 +57,7 @@ _gedit_cmd_documents_previous_document (GtkAction   *action,
 
 void
 _gedit_cmd_documents_next_document (GtkAction   *action,
-				   GeditWindow *window)
+				    GeditWindow *window)
 {
 	GtkNotebook *notebook;
 
@@ -67,7 +69,7 @@ _gedit_cmd_documents_next_document (GtkAction   *action,
 
 void
 _gedit_cmd_documents_move_to_new_window (GtkAction   *action,
-					GeditWindow *window)
+					 GeditWindow *window)
 {
 	GeditNotebook *old_notebook;
 	GeditTab *tab;
@@ -85,4 +87,27 @@ _gedit_cmd_documents_move_to_new_window (GtkAction   *action,
 
 	_gedit_window_move_tab_to_new_window (window, tab);
 }
+
+/* Methods releated with the tab groups */
+void
+_gedit_cmd_documents_new_tab_group (GtkAction   *action,
+				    GeditWindow *window)
+{
+	gedit_multi_notebook_add_new_notebook (window->priv->multi_notebook);
+}
+
+void
+_gedit_cmd_documents_previous_tab_group (GtkAction   *action,
+					 GeditWindow *window)
+{
+	gedit_multi_notebook_previous_notebook (window->priv->multi_notebook);
+}
+
+void
+_gedit_cmd_documents_next_tab_group (GtkAction   *action,
+				     GeditWindow *window)
+{
+	gedit_multi_notebook_next_notebook (window->priv->multi_notebook);
+}
+
 /* ex:ts=8:noet: */
