@@ -66,17 +66,14 @@ static void
 last_search_data_restore_position (GeditSearchDialog *dlg)
 {
 	LastSearchData *data;
-	
+
 	data = g_object_get_data (G_OBJECT (dlg), GEDIT_LAST_SEARCH_DATA_KEY);
-	
+
 	if (data != NULL)
 	{
 		gtk_window_move (GTK_WINDOW (dlg),
 				 data->x,
 				 data->y);
-		
-		gedit_search_dialog_present_with_time (dlg,
-						       GDK_CURRENT_TIME);
 	}
 }
 
@@ -84,19 +81,19 @@ static void
 last_search_data_store_position (GeditSearchDialog *dlg)
 {
 	LastSearchData *data;
-	
+
 	data = g_object_get_data (G_OBJECT (dlg), GEDIT_LAST_SEARCH_DATA_KEY);
-	
+
 	if (data == NULL)
 	{
 		data = g_slice_new (LastSearchData);
-		
+
 		g_object_set_data_full (G_OBJECT (dlg),
 					GEDIT_LAST_SEARCH_DATA_KEY,
 					data,
 					(GDestroyNotify) last_search_data_free);
 	}
-	
+
 	gtk_window_get_position (GTK_WINDOW (dlg),
 				 &data->x,
 				 &data->y);
@@ -116,16 +113,17 @@ text_found (GeditWindow *window,
 					     	        occurrences),
 					       occurrences);
 	}
+	else if (occurrences == 1)
+	{
+		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
+					       window->priv->generic_message_cid,
+					       _("Found and replaced one occurrence"));
+	}
 	else
 	{
-		if (occurrences == 1)
-			gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-						       window->priv->generic_message_cid,
-						       _("Found and replaced one occurrence"));
-		else
-			gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-						       window->priv->generic_message_cid,
-						       " ");
+		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
+					       window->priv->generic_message_cid,
+					       " ");
 	}
 }
 
@@ -187,17 +185,21 @@ run_search (GeditView   *view,
 	if (!found && wrap_around)
 	{
 		if (!search_backwards)
+		{
 			found = gedit_document_search_forward (doc,
 							       NULL,
 							       NULL, /* FIXME: set the end_inter */
 							       &match_start,
 							       &match_end);
+		}
 		else
+		{
 			found = gedit_document_search_backward (doc,
 							        NULL, /* FIXME: set the start_inter */
 							        NULL, 
 							        &match_start,
 							        &match_end);
+		}
 	}
 	
 	if (found)
@@ -454,6 +456,17 @@ search_dialog_response_cb (GeditSearchDialog *dialog,
 	}
 }
 
+static gboolean
+search_dialog_delete_event_cb (GtkWidget   *widget,
+			       GdkEventAny *event,
+			       gpointer     user_data)
+{
+	gedit_debug (DEBUG_COMMANDS);
+
+	/* prevent destruction */
+	return TRUE;
+}
+
 static void
 search_dialog_destroyed (GeditWindow       *window,
 			 GeditSearchDialog *dialog)
@@ -468,6 +481,34 @@ search_dialog_destroyed (GeditWindow       *window,
 			   NULL);
 }
 
+static GtkWidget *
+create_dialog (GeditWindow *window,
+	       gboolean     show_replace)
+{
+	GtkWidget *dialog;
+
+	dialog = gedit_search_dialog_new (GTK_WINDOW (window), show_replace);
+
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (search_dialog_response_cb),
+			  window);
+	g_signal_connect (dialog,
+			 "delete-event",
+			 G_CALLBACK (search_dialog_delete_event_cb),
+			 NULL);
+
+	g_object_set_data (G_OBJECT (window),
+			   GEDIT_SEARCH_DIALOG_KEY,
+			   dialog);
+
+	g_object_weak_ref (G_OBJECT (dialog),
+			   (GWeakNotify) search_dialog_destroyed,
+			   window);
+
+	return dialog;
+}
+
 void
 _gedit_cmd_search_find (GtkAction   *action,
 			GeditWindow *window)
@@ -485,21 +526,7 @@ _gedit_cmd_search_find (GtkAction   *action,
 
 	if (data == NULL)
 	{
-		search_dialog = gedit_search_dialog_new (GTK_WINDOW (window),
-							 FALSE);
-		
-		g_signal_connect (search_dialog,
-				  "response",
-				  G_CALLBACK (search_dialog_response_cb),
-				  window);
-		
-		g_object_set_data (G_OBJECT (window),
-				   GEDIT_SEARCH_DIALOG_KEY,
-				   search_dialog);
-		
-		g_object_weak_ref (G_OBJECT (search_dialog),
-				   (GWeakNotify) search_dialog_destroyed,
-				   window);
+		search_dialog = create_dialog (window, FALSE);
 	}
 	else
 	{
@@ -509,8 +536,10 @@ _gedit_cmd_search_find (GtkAction   *action,
 		
 		/* turn the dialog into a find dialog if needed */
 		if (gedit_search_dialog_get_show_replace (GEDIT_SEARCH_DIALOG (search_dialog)))
+		{
 			gedit_search_dialog_set_show_replace (GEDIT_SEARCH_DIALOG (search_dialog),
 							      FALSE);
+		}
 	}
 
 	doc = gedit_window_get_active_document (window);
@@ -533,6 +562,8 @@ _gedit_cmd_search_find (GtkAction   *action,
 
 	gtk_widget_show (search_dialog);
 	last_search_data_restore_position (GEDIT_SEARCH_DIALOG (search_dialog));
+	gedit_search_dialog_present_with_time (GEDIT_SEARCH_DIALOG (search_dialog),
+					       GDK_CURRENT_TIME);
 }
 
 void
@@ -549,24 +580,10 @@ _gedit_cmd_search_replace (GtkAction   *action,
 	gedit_debug (DEBUG_COMMANDS);
 
 	data = g_object_get_data (G_OBJECT (window), GEDIT_SEARCH_DIALOG_KEY);
-	
+
 	if (data == NULL)
 	{
-		replace_dialog = gedit_search_dialog_new (GTK_WINDOW (window),
-							  TRUE);
-		
-		g_signal_connect (replace_dialog,
-				  "response",
-				  G_CALLBACK (search_dialog_response_cb),
-				  window);
-		
-		g_object_set_data (G_OBJECT (window),
-				   GEDIT_SEARCH_DIALOG_KEY,
-				   replace_dialog);
-		
-		g_object_weak_ref (G_OBJECT (replace_dialog),
-				   (GWeakNotify) search_dialog_destroyed,
-				   window);
+		replace_dialog = create_dialog (window, TRUE);
 	}
 	else
 	{
@@ -576,8 +593,10 @@ _gedit_cmd_search_replace (GtkAction   *action,
 		
 		/* turn the dialog into a find dialog if needed */
 		if (!gedit_search_dialog_get_show_replace (GEDIT_SEARCH_DIALOG (replace_dialog)))
+		{
 			gedit_search_dialog_set_show_replace (GEDIT_SEARCH_DIALOG (replace_dialog),
 							      TRUE);
+		}
 	}
 
 	doc = gedit_window_get_active_document (window);
@@ -600,6 +619,8 @@ _gedit_cmd_search_replace (GtkAction   *action,
 
 	gtk_widget_show (replace_dialog);
 	last_search_data_restore_position (GEDIT_SEARCH_DIALOG (replace_dialog));
+	gedit_search_dialog_present_with_time (GEDIT_SEARCH_DIALOG (replace_dialog),
+					       GDK_CURRENT_TIME);
 }
 
 static void
@@ -703,3 +724,5 @@ _gedit_cmd_search_incremental_search (GtkAction   *action,
 			       GDK_k,
 			       GDK_CONTROL_MASK);
 }
+
+/* ex:ts=8:noet: */
