@@ -29,14 +29,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-spinner.h 5269 2006-10-19 15:56:44Z pborelli $
+ * $Id$
  */
 
 #ifndef __GEDIT_SPINNER_H__
 #define __GEDIT_SPINNER_H__
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkenums.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -94,3 +93,5 @@ void		gedit_spinner_set_size	(GeditSpinner *spinner,
 G_END_DECLS
 
 #endif /* __GEDIT_SPINNER_H__ */
+
+/* ex:ts=8:noet: */
