@@ -85,7 +85,7 @@ static const GtkActionEntry gedit_menu_entries[] =
 	  N_("Revert to a saved version of the file"), G_CALLBACK (_gedit_cmd_file_revert) },
 #if !GTK_CHECK_VERSION (2, 17, 4)
 	{ "FilePageSetup", GTK_STOCK_PAGE_SETUP, N_("Page Set_up..."), NULL,
-	  N_("Setup the page settings"), G_CALLBACK (_gedit_cmd_file_page_setup) },
+	  N_("Set up the page settings"), G_CALLBACK (_gedit_cmd_file_page_setup) },
 #endif
 	{ "FilePrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Previe_w"),"<control><shift>P",
 	  N_("Print preview"), G_CALLBACK (_gedit_cmd_file_print_preview) },
@@ -137,9 +137,15 @@ static const GtkActionEntry gedit_menu_entries[] =
 	  N_("Save all open files"), G_CALLBACK (_gedit_cmd_file_save_all) },
 	{ "FileCloseAll", GTK_STOCK_CLOSE, N_("_Close All"), "<shift><control>W",
 	  N_("Close all open files"), G_CALLBACK (_gedit_cmd_file_close_all) },
+	{ "DocumentsNewTabGroup", NULL, N_("_New Tab Group"), "<alt><control>N",
+	  N_("Create a new tab group"), G_CALLBACK (_gedit_cmd_documents_new_tab_group) },
+	{ "DocumentsPreviousTabGroup", NULL, N_("P_revious Tab Group"), "<shift><alt><control>Page_Up",
+	  N_("Switch to the previous tab group"), G_CALLBACK (_gedit_cmd_documents_previous_tab_group) },
+	{ "DocumentsNextTabGroup", NULL, N_("Nex_t Tab Group"), "<shift><alt><control>Page_Down",
+	  N_("Switch to the next tab group"), G_CALLBACK (_gedit_cmd_documents_next_tab_group) },
 	{ "DocumentsPreviousDocument", NULL, N_("_Previous Document"), "<alt><control>Page_Up",
 	  N_("Activate previous document"), G_CALLBACK (_gedit_cmd_documents_previous_document) },
-	{ "DocumentsNextDocument", NULL, N_("_Next Document"), "<alt><control>Page_Down",
+	{ "DocumentsNextDocument", NULL, N_("N_ext Document"), "<alt><control>Page_Down",
 	  N_("Activate next document"), G_CALLBACK (_gedit_cmd_documents_next_document) },
 	{ "DocumentsMoveToNewWindow", NULL, N_("_Move to New Window"), NULL,
 	  N_("Move the current document to a new window"), G_CALLBACK (_gedit_cmd_documents_move_to_new_window) }
@@ -168,7 +174,7 @@ static const GtkToggleActionEntry gedit_always_sensitive_toggle_menu_entries[] =
 	  N_("Show or hide the statusbar in the current window"),
 	  G_CALLBACK (_gedit_cmd_view_show_statusbar), TRUE },
 	{ "ViewFullscreen", GTK_STOCK_FULLSCREEN, NULL, "F11",
-	  N_("Edit text at fullscreen"),
+	  N_("Edit text in fullscreen"),
 	  G_CALLBACK (_gedit_cmd_view_toggle_fullscreen_mode), FALSE }
 };
 
@@ -186,3 +192,4 @@ static const GtkToggleActionEntry gedit_panes_toggle_menu_entries[] =
 G_END_DECLS
 
 #endif  /* __GEDIT_UI_H__  */
+/* ex:ts=8:noet: */
