@@ -32,8 +32,13 @@
 #define __GEDIT_WINDOW_PRIVATE_H__
 
 #include "gedit/gedit-window.h"
-#include "gedit-prefs-manager.h"
 #include "gedit-message-bus.h"
+#include "gedit-settings.h"
+#include "gedit-multi-notebook.h"
+
+#ifdef OS_OSX
+#include <ige-mac-integration.h>
+#endif
 
 G_BEGIN_DECLS
 
@@ -41,7 +46,11 @@ G_BEGIN_DECLS
 
 struct _GeditWindowPrivate
 {
-	GtkWidget      *notebook;
+	GSettings      *editor_settings;
+	GSettings      *ui_settings;
+	GSettings      *window_settings;
+
+	GeditMultiNotebook *multi_notebook;
 
 	GtkWidget      *side_panel;
 	GtkWidget      *bottom_panel;
@@ -60,9 +69,12 @@ struct _GeditWindowPrivate
 	gboolean        fullscreen_animation_enter;
 
 	/* statusbar and context ids for statusbar messages */
-	GtkWidget      *statusbar;	
+	GtkWidget      *statusbar;
 	guint           generic_message_cid;
 	guint           tip_message_cid;
+	guint 		bracket_match_message_cid;
+
+	/* signal handler ids */
 	guint 		tab_width_id;
 	guint 		spaces_instead_of_tabs_id;
 	guint 		language_changed_id;
@@ -70,13 +82,16 @@ struct _GeditWindowPrivate
 	/* Menus & Toolbars */
 	GtkUIManager   *manager;
 	GtkActionGroup *action_group;
-	GtkActionGroup *quit_action_group;
 	GtkActionGroup *always_sensitive_action_group;
+	GtkActionGroup *close_action_group;
+	GtkActionGroup *quit_action_group;
+	GtkActionGroup *panes_action_group;
 	GtkActionGroup *languages_action_group;
 	GtkActionGroup *documents_list_action_group;
 	guint           documents_list_menu_ui_id;
 	GtkWidget      *toolbar;
 	GtkWidget      *toolbar_recent_menu;
+	GtkWidget      *menubar;
 	GeditToolbarSetting toolbar_style;
 
 	/* recent files */
@@ -84,13 +99,10 @@ struct _GeditWindowPrivate
 	guint           recents_menu_ui_id;
 	gulong          recents_handler_id;
 
-	GeditTab       *active_tab;
-	gint            num_tabs;
-
 	gint            num_tabs_with_error;
 
 	gint            width;
-	gint            height;	
+	gint            height;
 	GdkWindowState  window_state;
 
 	gint            side_panel_size;
@@ -104,6 +116,10 @@ struct _GeditWindowPrivate
 
 	GFile          *default_location;
 
+#ifdef OS_OSX
+	IgeMacMenuGroup *mac_menu_group;
+#endif
+
 	gboolean        removing_tabs : 1;
 	gboolean        dispose_has_run : 1;
 };
@@ -111,3 +127,4 @@ struct _GeditWindowPrivate
 G_END_DECLS
 
 #endif  /* __GEDIT_WINDOW_PRIVATE_H__  */
+/* ex:ts=8:noet: */
