@@ -19,7 +19,7 @@
 import os
 import gtk
 from gtk import gdk
-import gnomevfs
+import gio
 import gedit
 #import gtksourceview
 from outputpanel import OutputPanel
@@ -31,14 +31,20 @@ def default(val, d):
     else:
         return d
 
+def current_word(document):
+    piter = document.get_iter_at_mark(document.get_insert())
+    start = piter.copy()
+    
+    if not piter.starts_word() and (piter.inside_word() or piter.ends_word()):
+        start.backward_word_start()
+    
+    if not piter.ends_word() and piter.inside_word():
+        piter.forward_word_end()
+            
+    return (start, piter)
+
 # ==== Capture related functions ====
-def capture_menu_action(action, window, node):
-
-    # Get the panel
-    panel = window.get_data("ExternalToolsPluginWindowData")._output_buffer
-    panel.show()
-    panel.clear()
-
+def run_external_tool(window, node):
     # Configure capture environment
     try:
         cwd = os.getcwd()
@@ -53,48 +59,97 @@ def capture_menu_action(action, window, node):
     if view is not None:
         # Environment vars relative to current document
         document = view.get_buffer()
-        uri = document.get_uri()
-        if uri is not None:
-            scheme = gnomevfs.get_uri_scheme(uri)
-            name = os.path.basename(uri)
-            capture.set_env(GEDIT_CURRENT_DOCUMENT_URI    = uri,
+        location = document.get_location()
+        
+        # Current line number
+        piter = document.get_iter_at_mark(document.get_insert())
+        capture.set_env(GEDIT_CURRENT_LINE_NUMBER=str(piter.get_line() + 1))
+        
+        # Current line text
+        piter.set_line_offset(0)
+        end = piter.copy()
+        
+        if not end.ends_line():
+            end.forward_to_line_end()
+        
+        capture.set_env(GEDIT_CURRENT_LINE=piter.get_text(end))
+        
+        # Selected text (only if input is not selection)
+        if node.input != 'selection' and node.input != 'selection-document':
+            bounds = document.get_selection_bounds()
+            
+            if bounds:
+                capture.set_env(GEDIT_SELECTED_TEXT=bounds[0].get_text(bounds[1]))
+        
+        bounds = current_word(document)
+        capture.set_env(GEDIT_CURRENT_WORD=bounds[0].get_text(bounds[1]))
+        
+        capture.set_env(GEDIT_CURRENT_DOCUMENT_TYPE=document.get_mime_type())
+        
+        if location is not None:
+            scheme = location.get_uri_scheme()
+            name = location.get_basename()
+            capture.set_env(GEDIT_CURRENT_DOCUMENT_URI    = location.get_uri(),
                             GEDIT_CURRENT_DOCUMENT_NAME   = name,
                             GEDIT_CURRENT_DOCUMENT_SCHEME = scheme)
-            if scheme == 'file':
-                path = gnomevfs.get_local_path_from_uri(uri)
+            if gedit.utils.location_has_file_scheme(location):
+                path = location.get_path()
                 cwd = os.path.dirname(path)
                 capture.set_cwd(cwd)
                 capture.set_env(GEDIT_CURRENT_DOCUMENT_PATH = path,
                                 GEDIT_CURRENT_DOCUMENT_DIR  = cwd)
 
-        documents_uri = [doc.get_uri()
-                                 for doc in window.get_documents()
-                                 if doc.get_uri() is not None]
-        documents_path = [gnomevfs.get_local_path_from_uri(uri)
-                                 for uri in documents_uri
-                                 if gnomevfs.get_uri_scheme(uri) == 'file']
+        documents_location = [doc.get_location()
+                              for doc in window.get_documents()
+                              if doc.get_location() is not None]
+        documents_uri = [location.get_uri()
+                         for location in documents_location
+                         if location.get_uri() is not None]
+        documents_path = [location.get_path()
+                          for location in documents_location
+                          if gedit.utils.location_has_file_scheme(location)]
         capture.set_env(GEDIT_DOCUMENTS_URI  = ' '.join(documents_uri),
                         GEDIT_DOCUMENTS_PATH = ' '.join(documents_path))
 
-    capture.set_flags(capture.CAPTURE_BOTH)
+    flags = capture.CAPTURE_BOTH
+    
+    if not node.has_hash_bang():
+        flags |= capture.CAPTURE_NEEDS_SHELL
 
-    # Assign the error output to the output panel
-    panel.process = capture
+    capture.set_flags(flags)
 
     # Get input text
     input_type = node.input
     output_type = node.output
 
+    # Get the panel
+    panel = window.get_data("ExternalToolsPluginWindowData")._output_buffer
+    panel.clear()
+
+    if output_type == 'output-panel':
+        panel.show()
+
+    # Assign the error output to the output panel
+    panel.set_process(capture)
+
     if input_type != 'nothing' and view is not None:
         if input_type == 'document':
             start, end = document.get_bounds()
-        elif input_type == 'selection':
+        elif input_type == 'selection' or input_type == 'selection-document':
             try:
                 start, end = document.get_selection_bounds()
+                
+                print start, end
             except ValueError:
-                start, end = document.get_bounds()
-                if output_type == 'replace-selection':
-                    document.select_range(start, end)
+                if input_type == 'selection-document':
+                    start, end = document.get_bounds()
+
+                    if output_type == 'replace-selection':
+                        document.select_range(start, end)
+                else:
+                    start = document.get_iter_at_mark(document.get_insert())
+                    end = start.copy()
+                    
         elif input_type == 'line':
             start = document.get_iter_at_mark(document.get_insert())
             end = start.copy()
@@ -127,7 +182,7 @@ def capture_menu_action(action, window, node):
         document.begin_user_action()
         view.set_editable(False)
         view.set_cursor_visible(False)
-    elif output_type != 'output-panel' and view is not None:
+    elif output_type != 'output-panel' and output_type != 'nothing' and view is not None:
         document.begin_user_action()
         view.set_editable(False)
         view.set_cursor_visible(False)
@@ -143,41 +198,95 @@ def capture_menu_action(action, window, node):
         else:
             pos = document.get_end_iter()
         capture.connect('stdout-line', capture_stdout_line_document, document, pos)
-    else:
+    elif output_type != 'nothing':
         capture.connect('stdout-line', capture_stdout_line_panel, panel)
         document.begin_user_action()
 
-    capture.connect('stderr-line',   capture_stderr_line_panel,   panel)
-    capture.connect('begin-execute', capture_begin_execute_panel, panel, node.name)
-    capture.connect('end-execute',   capture_end_execute_panel,   panel, view,
-                    output_type in ('new-document','replace-document'))
+    capture.connect('stderr-line', capture_stderr_line_panel, panel)
+    capture.connect('begin-execute', capture_begin_execute_panel, panel, view, node.name)    
+    capture.connect('end-execute', capture_end_execute_panel, panel, view, output_type)
 
     # Run the command
-    view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(gdk.Cursor(gdk.WATCH))
     capture.execute()
-    document.end_user_action()
+    
+    if output_type != 'nothing':
+        document.end_user_action()
+
+class MultipleDocumentsSaver:
+    def __init__(self, window, docs, node):
+        self._window = window
+        self._node = node
+        self._error = False
+
+        self._counter = len(docs)
+        self._signal_ids = {}
+        self._counter = 0
+
+        signals = {}
+
+        for doc in docs:
+            signals[doc] = doc.connect('saving', self.on_document_saving)
+            gedit.commands.save_document(window, doc)
+            doc.disconnect(signals[doc])
+    
+    def on_document_saving(self, doc, size, total_size):
+        self._counter += 1
+        self._signal_ids[doc] = doc.connect('saved', self.on_document_saved)
+
+    def on_document_saved(self, doc, error):
+        if error:
+            self._error = True
+        
+        doc.disconnect(self._signal_ids[doc])
+        del self._signal_ids[doc]
+        
+        self._counter -= 1
+        
+        if self._counter == 0 and not self._error:
+            run_external_tool(self._window, self._node)
+
+def capture_menu_action(action, window, node):
+    if node.save_files == 'document' and window.get_active_document():
+        MultipleDocumentsSaver(window, [window.get_active_document()], node)
+        return
+    elif node.save_files == 'all':
+        MultipleDocumentsSaver(window, window.get_documents(), node)
+        return
+
+    run_external_tool(window, node)
 
 def capture_stderr_line_panel(capture, line, panel):
+    if not panel.visible():
+        panel.show()
+
     panel.write(line, panel.error_tag)
 
-def capture_begin_execute_panel(capture, panel, label):
+def capture_begin_execute_panel(capture, panel, view, label):
+    view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(gdk.Cursor(gdk.WATCH))
+
     panel['stop'].set_sensitive(True)
     panel.clear()
     panel.write(_("Running tool:"), panel.italic_tag);
     panel.write(" %s\n\n" % label, panel.bold_tag);
 
-def capture_end_execute_panel(capture, exit_code, panel, view, update_type):
+def capture_end_execute_panel(capture, exit_code, panel, view, output_type):
     panel['stop'].set_sensitive(False)
 
-    if update_type:
+    if output_type in ('new-document','replace-document'):
         doc = view.get_buffer()
         start = doc.get_start_iter()
         end = start.copy()
         end.forward_chars(300)
+        uri = ''
 
-        mtype = gnomevfs.get_mime_type_for_data(doc.get_text(start, end))
+        mtype = gio.content_type_guess(data=doc.get_text(start, end))
         lmanager = gedit.get_language_manager()
-        language = gedit.language_manager_get_language_from_mime_type(lmanager, mtype)
+        
+        location = doc.get_location()
+        if location:
+            uri = location.get_uri()
+        language = lmanager.guess_language(uri, mtype)
+        
         if language is not None:
             doc.set_language(language)
 
