@@ -1,5 +1,5 @@
 /*
- * gedit-file-browser-view.c - Gedit plugin providing easy file access 
+ * gedit-file-browser-view.c - Gedit plugin providing easy file access
  * from the sidepanel
  *
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
@@ -20,10 +20,13 @@
  */
 
 #include <string.h>
+
 #include <gio/gio.h>
-#include <gedit/gedit-plugin.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <gedit/gedit-plugin.h>
+#include <gedit/gseal-gtk-compat.h>
+
 #include "gedit-file-browser-store.h"
 #include "gedit-file-bookmarks-store.h"
 #include "gedit-file-browser-view.h"
@@ -34,7 +37,7 @@
 		G_TYPE_INSTANCE_GET_PRIVATE((object), \
 		GEDIT_TYPE_FILE_BROWSER_VIEW, GeditFileBrowserViewPrivate))
 
-struct _GeditFileBrowserViewPrivate 
+struct _GeditFileBrowserViewPrivate
 {
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *pixbuf_renderer;
@@ -45,26 +48,27 @@ struct _GeditFileBrowserViewPrivate
 
 	GdkCursor *busy_cursor;
 
-	/* CLick policy */
+	/* Click policy */
 	GeditFileBrowserViewClickPolicy click_policy;
-	GtkTreePath *double_click_path[2]; /* Both clicks in a double click need to be on the same row */
+	/* Both clicks in a double click need to be on the same row */
+	GtkTreePath *double_click_path[2];
 	GtkTreePath *hover_path;
 	GdkCursor *hand_cursor;
 	gboolean ignore_release;
 	gboolean selected_on_button_down;
 	gint drag_button;
 	gboolean drag_started;
-	
+
 	gboolean restore_expand_state;
 	gboolean is_refresh;
-	GHashTable * expand_state;
+	GHashTable *expand_state;
 };
 
 /* Properties */
 enum
 {
 	PROP_0,
-	
+
 	PROP_CLICK_POLICY,
 	PROP_RESTORE_EXPAND_STATE
 };
@@ -88,32 +92,32 @@ static const GtkTargetEntry drag_source_targets[] = {
 GEDIT_PLUGIN_DEFINE_TYPE (GeditFileBrowserView, gedit_file_browser_view,
 	                  GTK_TYPE_TREE_VIEW)
 
-static void on_cell_edited 		(GtkCellRendererText 	* cell, 
-				 	 gchar 			* path,
-				 	 gchar 			* new_text,
-				 	GeditFileBrowserView 	* tree_view);
+static void on_cell_edited 		(GtkCellRendererText    *cell,
+				 	 gchar                  *path,
+				 	 gchar                  *new_text,
+				 	GeditFileBrowserView    *tree_view);
 
-static void on_begin_refresh 		(GeditFileBrowserStore 	* model, 
-					 GeditFileBrowserView 	* view);
-static void on_end_refresh 		(GeditFileBrowserStore 	* model, 
-					 GeditFileBrowserView 	* view);
+static void on_begin_refresh 		(GeditFileBrowserStore  *model,
+					 GeditFileBrowserView   *view);
+static void on_end_refresh 		(GeditFileBrowserStore  *model,
+					 GeditFileBrowserView   *view);
 
-static void on_unload			(GeditFileBrowserStore 	* model, 
-					 gchar const		* uri,
-					 GeditFileBrowserView 	* view);
+static void on_unload			(GeditFileBrowserStore  *model,
+					 GFile                  *location,
+					 GeditFileBrowserView   *view);
+
+static void on_row_inserted		(GeditFileBrowserStore  *model,
+					 GtkTreePath            *path,
+					 GtkTreeIter            *iter,
+					 GeditFileBrowserView   *view);
 
-static void on_row_inserted		(GeditFileBrowserStore 	* model, 
-					 GtkTreePath		* path,
-					 GtkTreeIter		* iter,
-					 GeditFileBrowserView 	* view);
-		 
 static void
-gedit_file_browser_view_finalize (GObject * object)
+gedit_file_browser_view_finalize (GObject *object)
 {
-	GeditFileBrowserView *obj = GEDIT_FILE_BROWSER_VIEW(object);
-	
+	GeditFileBrowserView *obj = GEDIT_FILE_BROWSER_VIEW (object);
+
 	if (obj->priv->hand_cursor)
-		gdk_cursor_unref(obj->priv->hand_cursor);
+		gdk_cursor_unref (obj->priv->hand_cursor);
 
 	if (obj->priv->hover_path)
 		gtk_tree_path_free (obj->priv->hover_path);
@@ -126,51 +130,38 @@ gedit_file_browser_view_finalize (GObject * object)
 
 	gdk_cursor_unref (obj->priv->busy_cursor);
 
-	G_OBJECT_CLASS (gedit_file_browser_view_parent_class)->
-	    finalize (object);
+	G_OBJECT_CLASS (gedit_file_browser_view_parent_class)->finalize (object);
 }
 
 static void
-add_expand_state (GeditFileBrowserView * view,
-		  gchar const * uri)
+add_expand_state (GeditFileBrowserView *view,
+		  GFile                *location)
 {
-	GFile * file;
-	
-	if (!uri)
+	if (!location)
 		return;
 
-	file = g_file_new_for_uri (uri);
-	
 	if (view->priv->expand_state)
-		g_hash_table_insert (view->priv->expand_state, file, file);
-	else
-		g_object_unref (file);
+		g_hash_table_insert (view->priv->expand_state, location, g_object_ref (location));
 }
 
 static void
-remove_expand_state (GeditFileBrowserView * view,
-		     gchar const * uri)
+remove_expand_state (GeditFileBrowserView *view,
+		     GFile                *location)
 {
-	GFile * file;
-	
-	if (!uri)
+	if (!location)
 		return;
 
-	file = g_file_new_for_uri (uri);
-	
 	if (view->priv->expand_state)
-		g_hash_table_remove (view->priv->expand_state, file);
-
-	g_object_unref (file);
+		g_hash_table_remove (view->priv->expand_state, location);
 }
 
 static void
-row_expanded (GtkTreeView * tree_view,
-	      GtkTreeIter * iter,
-	      GtkTreePath * path)
+row_expanded (GtkTreeView *tree_view,
+	      GtkTreeIter *iter,
+	      GtkTreePath *path)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (tree_view);
-	gchar * uri;
+	GFile *location;
 
 	if (GTK_TREE_VIEW_CLASS (gedit_file_browser_view_parent_class)->row_expanded)
 		GTK_TREE_VIEW_CLASS (gedit_file_browser_view_parent_class)->row_expanded (tree_view, iter, path);
@@ -181,13 +172,12 @@ row_expanded (GtkTreeView * tree_view,
 	if (view->priv->restore_expand_state)
 	{
 		gtk_tree_model_get (view->priv->model,
-				    iter, 
-				    GEDIT_FILE_BROWSER_STORE_COLUMN_URI,
-				    &uri,
+				    iter,
+				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
+				    &location,
 				    -1);
 
-		add_expand_state (view, uri);
-		g_free (uri);
+		add_expand_state (view, location);
 	}
 
 	_gedit_file_browser_store_iter_expanded (GEDIT_FILE_BROWSER_STORE (view->priv->model),
@@ -195,29 +185,28 @@ row_expanded (GtkTreeView * tree_view,
 }
 
 static void
-row_collapsed (GtkTreeView * tree_view,
-	       GtkTreeIter * iter,
-	       GtkTreePath * path)
+row_collapsed (GtkTreeView *tree_view,
+	       GtkTreeIter *iter,
+	       GtkTreePath *path)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (tree_view);
-	gchar * uri;
+	GFile *location;
 
 	if (GTK_TREE_VIEW_CLASS (gedit_file_browser_view_parent_class)->row_collapsed)
 		GTK_TREE_VIEW_CLASS (gedit_file_browser_view_parent_class)->row_collapsed (tree_view, iter, path);
 
 	if (!GEDIT_IS_FILE_BROWSER_STORE (view->priv->model))
 		return;
-	
+
 	if (view->priv->restore_expand_state)
 	{
-		gtk_tree_model_get (view->priv->model, 
-				    iter, 
-				    GEDIT_FILE_BROWSER_STORE_COLUMN_URI,
-				    &uri,
+		gtk_tree_model_get (view->priv->model,
+				    iter,
+				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
+				    &location,
 				    -1);
 
-		remove_expand_state (view, uri);
-		g_free (uri);
+		remove_expand_state (view, location);
 	}
 
 	_gedit_file_browser_store_iter_collapsed (GEDIT_FILE_BROWSER_STORE (view->priv->model),
@@ -225,28 +214,30 @@ row_collapsed (GtkTreeView * tree_view,
 }
 
 static gboolean
-leave_notify_event (GtkWidget *widget,
+leave_notify_event (GtkWidget        *widget,
 		    GdkEventCrossing *event)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (widget);
 
 	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE &&
-	    view->priv->hover_path != NULL) {
+	    view->priv->hover_path != NULL)
+	{
 		gtk_tree_path_free (view->priv->hover_path);
 		view->priv->hover_path = NULL;
 	}
 
-	// Chainup
+	/* Chainup */
 	return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->leave_notify_event (widget, event);
 }
 
 static gboolean
-enter_notify_event (GtkWidget *widget,
+enter_notify_event (GtkWidget        *widget,
 		    GdkEventCrossing *event)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (widget);
 
-	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
+	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE)
+	{
 		if (view->priv->hover_path != NULL)
 			gtk_tree_path_free (view->priv->hover_path);
 
@@ -256,42 +247,50 @@ enter_notify_event (GtkWidget *widget,
 					       NULL, NULL, NULL);
 
 		if (view->priv->hover_path != NULL)
+		{
 			gdk_window_set_cursor (gtk_widget_get_window (widget),
 					       view->priv->hand_cursor);
+		}
 	}
 
-	// Chainup
+	/* Chainup */
 	return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->enter_notify_event (widget, event);
 }
 
 static gboolean
-motion_notify_event (GtkWidget * widget,
-		     GdkEventMotion * event)
+motion_notify_event (GtkWidget *widget,
+		     GdkEventMotion *event)
 {
 	GtkTreePath *old_hover_path;
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (widget);
 
-	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
+	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE)
+	{
 		old_hover_path = view->priv->hover_path;
 		gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
 					       event->x, event->y,
 					       &view->priv->hover_path,
 					       NULL, NULL, NULL);
 
-		if ((old_hover_path != NULL) != (view->priv->hover_path != NULL)) {
+		if ((old_hover_path != NULL) != (view->priv->hover_path != NULL))
+		{
 			if (view->priv->hover_path != NULL)
+			{
 				gdk_window_set_cursor (gtk_widget_get_window (widget),
 						       view->priv->hand_cursor);
+			}
 			else
+			{
 				gdk_window_set_cursor (gtk_widget_get_window (widget),
 						       NULL);
+			}
 		}
 
 		if (old_hover_path != NULL)
 			gtk_tree_path_free (old_hover_path);
 	}
-	
-	// Chainup
+
+	/* Chainup */
 	return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->motion_notify_event (widget, event);
 }
 
@@ -305,31 +304,39 @@ set_click_policy_property (GeditFileBrowserView            *obj,
 
 	obj->priv->click_policy = click_policy;
 
-	if (click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
+	if (click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE)
+	{
 		if (obj->priv->hand_cursor == NULL)
-			obj->priv->hand_cursor = gdk_cursor_new(GDK_HAND2);
-	} else if (click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE) {
-		if (obj->priv->hover_path != NULL) {
+			obj->priv->hand_cursor = gdk_cursor_new (GDK_HAND2);
+	}
+	else if (click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE)
+	{
+		if (obj->priv->hover_path != NULL)
+		{
 			if (gtk_tree_model_get_iter (GTK_TREE_MODEL (obj->priv->model),
 						     &iter, obj->priv->hover_path))
+			{
 				gtk_tree_model_row_changed (GTK_TREE_MODEL (obj->priv->model),
 							    obj->priv->hover_path, &iter);
+			}
 
 			gtk_tree_path_free (obj->priv->hover_path);
 			obj->priv->hover_path = NULL;
 		}
 
-		if (GTK_WIDGET_REALIZED (GTK_WIDGET (obj))) {
+		if (gtk_widget_get_realized (GTK_WIDGET (obj)))
+		{
 			win = gtk_widget_get_window (GTK_WIDGET (obj));
 			gdk_window_set_cursor (win, NULL);
-			
+
 			display = gtk_widget_get_display (GTK_WIDGET (obj));
 
 			if (display != NULL)
 				gdk_display_flush (display);
 		}
 
-		if (obj->priv->hand_cursor) {
+		if (obj->priv->hand_cursor)
+		{
 			gdk_cursor_unref (obj->priv->hand_cursor);
 			obj->priv->hand_cursor = NULL;
 		}
@@ -337,14 +344,15 @@ set_click_policy_property (GeditFileBrowserView            *obj,
 }
 
 static void
-directory_activated (GeditFileBrowserView *view, 
+directory_activated (GeditFileBrowserView *view,
 		     GtkTreeIter          *iter)
 {
 	gedit_file_browser_store_set_virtual_root (GEDIT_FILE_BROWSER_STORE (view->priv->model), iter);
 }
 
 static void
-activate_selected_files (GeditFileBrowserView *view) {
+activate_selected_files (GeditFileBrowserView *view)
+{
 	GtkTreeView *tree_view = GTK_TREE_VIEW (view);
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (tree_view);
 	GList *rows, *row;
@@ -354,36 +362,33 @@ activate_selected_files (GeditFileBrowserView *view) {
 	GeditFileBrowserStoreFlag flags;
 
 	rows = gtk_tree_selection_get_selected_rows (selection, &view->priv->model);
-	
-	for (row = rows; row; row = row->next) {
+
+	for (row = rows; row; row = row->next)
+	{
 		path = (GtkTreePath *)(row->data);
-		
+
 		/* Get iter from path */
 		if (!gtk_tree_model_get_iter (view->priv->model, &iter, path))
 			continue;
-		
+
 		gtk_tree_model_get (view->priv->model, &iter, GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags, -1);
 
-		if (FILE_IS_DIR (flags)) {
-			if (directory == NULL)
-				directory = path;
-	
-		} else if (!FILE_IS_DUMMY (flags)) {
+		if (FILE_IS_DIR (flags) && directory == NULL)
+			directory = path;
+		else if (!FILE_IS_DUMMY (flags))
 			g_signal_emit (view, signals[FILE_ACTIVATED], 0, &iter);
-		}
 	}
-	
-	if (directory != NULL) {
-		if (gtk_tree_model_get_iter (view->priv->model, &iter, directory))
-			g_signal_emit (view, signals[DIRECTORY_ACTIVATED], 0, &iter);
-	}
-			
+
+	if (directory != NULL && gtk_tree_model_get_iter (view->priv->model, &iter, directory))
+		g_signal_emit (view, signals[DIRECTORY_ACTIVATED], 0, &iter);
+
 	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
 	g_list_free (rows);
 }
 
 static void
-activate_selected_bookmark (GeditFileBrowserView *view) {
+activate_selected_bookmark (GeditFileBrowserView *view)
+{
 	GtkTreeView *tree_view = GTK_TREE_VIEW (view);
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (tree_view);
 	GtkTreeIter iter;
@@ -427,10 +432,10 @@ drag_begin (GtkWidget      *widget,
 	    GdkDragContext *context)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (widget);
-	
+
 	view->priv->drag_button = 0;
 	view->priv->drag_started = TRUE;
-	
+
 	/* Chain up */
 	GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->drag_begin (widget, context);
 }
@@ -442,25 +447,32 @@ did_not_drag (GeditFileBrowserView *view,
 	GtkTreeView *tree_view;
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
-	
+
 	tree_view = GTK_TREE_VIEW (view);
 	selection = gtk_tree_view_get_selection (tree_view);
 
 	if (gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y,
-					   &path, NULL, NULL, NULL)) {
-		if ((view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE)
-		    && !button_event_modifies_selection(event) 
-		    && (event->button == 1 || event->button == 2)) {
+					   &path, NULL, NULL, NULL))
+	{
+		if ((view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) &&
+		    !button_event_modifies_selection (event) &&
+		    (event->button == 1 || event->button == 2))
+		{
 		    	/* Activate all selected items, and leave them selected */
 			activate_selected_items (view);
-		} else if ((event->button == 1 || event->button == 2)
-		    && ((event->state & GDK_CONTROL_MASK) != 0 ||
-			(event->state & GDK_SHIFT_MASK) == 0)
-		    && view->priv->selected_on_button_down) {
-			if (!button_event_modifies_selection (event)) {
+		}
+		else if ((event->button == 1 || event->button == 2) &&
+		         ((event->state & GDK_CONTROL_MASK) != 0 ||
+		          (event->state & GDK_SHIFT_MASK) == 0) &&
+		         view->priv->selected_on_button_down)
+		{
+			if (!button_event_modifies_selection (event))
+			{
 				gtk_tree_selection_unselect_all (selection);
 				gtk_tree_selection_select_path (selection, path);
-			} else {
+			}
+			else
+			{
 				gtk_tree_selection_unselect_path (selection, path);
 			}
 		}
@@ -470,21 +482,21 @@ did_not_drag (GeditFileBrowserView *view,
 }
 
 static gboolean
-button_release_event (GtkWidget       *widget,
+button_release_event (GtkWidget      *widget,
 		      GdkEventButton *event)
 {
 	GeditFileBrowserView *view = GEDIT_FILE_BROWSER_VIEW (widget);
 
-	if (event->button == view->priv->drag_button) {
+	if (event->button == view->priv->drag_button)
+	{
 		view->priv->drag_button = 0;
 
-		if (!view->priv->drag_started &&
-		    !view->priv->ignore_release)
+		if (!view->priv->drag_started && !view->priv->ignore_release)
 			did_not_drag (view, event);
 	}
-	
+
 	/* Chain up */
-	return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->button_release_event (widget, event);		
+	return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->button_release_event (widget, event);
 }
 
 static gboolean
@@ -503,14 +515,14 @@ button_press_event (GtkWidget      *widget,
 	gboolean on_expander;
 	gboolean call_parent;
 	gboolean selected;
-	GtkWidgetClass *widget_parent = GTK_WIDGET_CLASS(gedit_file_browser_view_parent_class);
+	GtkWidgetClass *widget_parent = GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class);
 
 	tree_view = GTK_TREE_VIEW (widget);
 	view = GEDIT_FILE_BROWSER_VIEW (widget);
 	selection = gtk_tree_view_get_selection (tree_view);
 
 	/* Get double click time */
-	g_object_get (G_OBJECT (gtk_widget_get_settings (widget)), 
+	g_object_get (G_OBJECT (gtk_widget_get_settings (widget)),
 		      "gtk-double-click-time", &double_click_time,
 		      NULL);
 
@@ -519,12 +531,13 @@ button_press_event (GtkWidget      *widget,
 		click_count++;
 	else
 		click_count = 0;
-	
+
 	last_click_time = event->time;
 
 	/* Ignore double click if we are in single click mode */
-	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE && 
-	    click_count >= 2) {
+	if (view->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE &&
+	    click_count >= 2)
+	{
 		return TRUE;
 	}
 
@@ -532,11 +545,13 @@ button_press_event (GtkWidget      *widget,
 	call_parent = TRUE;
 
 	if (gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y,
-					   &path, NULL, NULL, NULL)) {
+					   &path, NULL, NULL, NULL))
+	{
 		/* Keep track of path of last click so double clicks only happen
 		 * on the same item */
-		if ((event->button == 1 || event->button == 2)  && 
-		    event->type == GDK_BUTTON_PRESS) {
+		if ((event->button == 1 || event->button == 2)  &&
+		    event->type == GDK_BUTTON_PRESS)
+		{
 			if (view->priv->double_click_path[1])
 				gtk_tree_path_free (view->priv->double_click_path[1]);
 
@@ -544,14 +559,20 @@ button_press_event (GtkWidget      *widget,
 			view->priv->double_click_path[0] = gtk_tree_path_copy (path);
 		}
 
-		if (event->type == GDK_2BUTTON_PRESS) {
+		if (event->type == GDK_2BUTTON_PRESS)
+		{
+			/* Chain up, must be before activating the selected
+			   items because this will cause the view to grab focus */
+			widget_parent->button_press_event (widget, event);
+
 			if (view->priv->double_click_path[1] &&
 			    gtk_tree_path_compare (view->priv->double_click_path[0], view->priv->double_click_path[1]) == 0)
+			{
 				activate_selected_items (view);
-			
-			/* Chain up */
-			widget_parent->button_press_event (widget, event);
-		} else {
+			}
+		}
+		else
+		{
 			/* We're going to filter out some situations where
 			 * we can't let the default code run because all
 			 * but one row would be would be deselected. We don't
@@ -564,7 +585,8 @@ button_press_event (GtkWidget      *widget,
 
 			if ((event->button == 1 || event->button == 2) &&
 			    ((event->state & GDK_CONTROL_MASK) != 0 ||
-			     (event->state & GDK_SHIFT_MASK) == 0)) {
+			     (event->state & GDK_SHIFT_MASK) == 0))
+			{
 				gtk_widget_style_get (widget,
 						      "expander-size", &expander_size,
 						      "horizontal-separator", &horizontal_separator,
@@ -574,35 +596,47 @@ button_press_event (GtkWidget      *widget,
 
 				view->priv->selected_on_button_down = selected;
 
-				if (selected) {
+				if (selected)
+				{
 					call_parent = on_expander || gtk_tree_selection_count_selected_rows (selection) == 1;
 					view->priv->ignore_release = call_parent && view->priv->click_policy != GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE;
-				} else if  ((event->state & GDK_CONTROL_MASK) != 0) {
+				}
+				else if  ((event->state & GDK_CONTROL_MASK) != 0)
+				{
 					call_parent = FALSE;
 					gtk_tree_selection_select_path (selection, path);
-				} else {
+				}
+				else
+				{
 					view->priv->ignore_release = on_expander;
 				}
 			}
-			
-			if (call_parent) {
+
+			if (call_parent)
+			{
 				/* Chain up */
 				widget_parent->button_press_event (widget, event);
-			} else if (selected) {
+			}
+			else if (selected)
+			{
 				gtk_widget_grab_focus (widget);
 			}
-			
+
 			if ((event->button == 1 || event->button == 2) &&
-			    event->type == GDK_BUTTON_PRESS) {
+			    event->type == GDK_BUTTON_PRESS)
+			{
 				view->priv->drag_started = FALSE;
 				view->priv->drag_button = event->button;
 			}
 		}
 
 		gtk_tree_path_free (path);
-	} else {
-		if ((event->button == 1 || event->button == 2)  && 
-		    event->type == GDK_BUTTON_PRESS) {
+	}
+	else
+	{
+		if ((event->button == 1 || event->button == 2)  &&
+		    event->type == GDK_BUTTON_PRESS)
+		{
 			if (view->priv->double_click_path[1])
 				gtk_tree_path_free (view->priv->double_click_path[1]);
 
@@ -632,128 +666,135 @@ key_press_event (GtkWidget   *widget,
 
 	modifiers = gtk_accelerator_get_default_mod_mask ();
 
-	switch (event->keyval) {
-	case GDK_space:
-		if (event->state & GDK_CONTROL_MASK) {
-			handled = FALSE;
-			break;
-		}
-		if (!GTK_WIDGET_HAS_FOCUS (widget)) {
-			handled = FALSE;
-			break;
-		}
+	switch (event->keyval)
+	{
+		case GDK_space:
+			if (event->state & GDK_CONTROL_MASK)
+			{
+				handled = FALSE;
+				break;
+			}
+			if (!gtk_widget_has_focus (widget))
+			{
+				handled = FALSE;
+				break;
+			}
 
-		activate_selected_items (view);
-		handled = TRUE;
-		break;
-
-	case GDK_Return:
-	case GDK_KP_Enter:
-		activate_selected_items (view);
-		handled = TRUE;
-		break;
-
-	case GDK_h:
-		if ((event->state & modifiers) == GDK_CONTROL_MASK) {
-			toggle_hidden_filter (view);
+			activate_selected_items (view);
 			handled = TRUE;
 			break;
-		}
 
-	default:
-		handled = FALSE;
+		case GDK_Return:
+		case GDK_KP_Enter:
+			activate_selected_items (view);
+			handled = TRUE;
+			break;
+
+		case GDK_h:
+			if ((event->state & modifiers) == GDK_CONTROL_MASK)
+			{
+				toggle_hidden_filter (view);
+				handled = TRUE;
+				break;
+			}
+
+		default:
+			handled = FALSE;
+			break;
 	}
 
 	/* Chain up */
 	if (!handled)
 		return GTK_WIDGET_CLASS (gedit_file_browser_view_parent_class)->key_press_event (widget, event);
-	
+
 	return TRUE;
 }
 
 static void
-fill_expand_state (GeditFileBrowserView * view, GtkTreeIter * iter)
+fill_expand_state (GeditFileBrowserView *view,
+		   GtkTreeIter *iter)
 {
-	GtkTreePath * path;
+	GtkTreePath *path;
 	GtkTreeIter child;
-	gchar * uri;
-	
+	GFile *location;
+
 	if (!gtk_tree_model_iter_has_child (view->priv->model, iter))
 		return;
-	
+
 	path = gtk_tree_model_get_path (view->priv->model, iter);
-	
+
 	if (gtk_tree_view_row_expanded (GTK_TREE_VIEW (view), path))
 	{
-		gtk_tree_model_get (view->priv->model, 
-				    iter, 
-				    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, 
-				    &uri, 
+		gtk_tree_model_get (view->priv->model,
+				    iter,
+				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
+				    &location,
 				    -1);
 
-		add_expand_state (view, uri);
-		g_free (uri);
+		add_expand_state (view, location);
 	}
-	
+
 	if (gtk_tree_model_iter_children (view->priv->model, &child, iter))
 	{
-		do {
+		do
+		{
 			fill_expand_state (view, &child);
-		} while (gtk_tree_model_iter_next (view->priv->model, &child));
+		}
+		while (gtk_tree_model_iter_next (view->priv->model, &child));
 	}
-	
+
 	gtk_tree_path_free (path);
 }
 
 static void
-uninstall_restore_signals (GeditFileBrowserView * tree_view,
-			   GtkTreeModel * model)
+uninstall_restore_signals (GeditFileBrowserView *tree_view,
+			   GtkTreeModel         *model)
 {
-	g_signal_handlers_disconnect_by_func (model, 
-					      on_begin_refresh, 
-					      tree_view);
-					      
-	g_signal_handlers_disconnect_by_func (model, 
-					      on_end_refresh, 
-					      tree_view);
-					      
-	g_signal_handlers_disconnect_by_func (model, 
-					      on_unload, 
+	g_signal_handlers_disconnect_by_func (model,
+					      on_begin_refresh,
 					      tree_view);
 
-	g_signal_handlers_disconnect_by_func (model, 
-					      on_row_inserted, 
+	g_signal_handlers_disconnect_by_func (model,
+					      on_end_refresh,
+					      tree_view);
+
+	g_signal_handlers_disconnect_by_func (model,
+					      on_unload,
+					      tree_view);
+
+	g_signal_handlers_disconnect_by_func (model,
+					      on_row_inserted,
 					      tree_view);
 }
 
 static void
-install_restore_signals (GeditFileBrowserView * tree_view,
-			 GtkTreeModel * model)
+install_restore_signals (GeditFileBrowserView *tree_view,
+			 GtkTreeModel         *model)
 {
-	g_signal_connect (model, 
+	g_signal_connect (model,
 			  "begin-refresh",
-			  G_CALLBACK (on_begin_refresh), 
+			  G_CALLBACK (on_begin_refresh),
 			  tree_view);
 
-	g_signal_connect (model, 
+	g_signal_connect (model,
 			  "end-refresh",
-			  G_CALLBACK (on_end_refresh), 
+			  G_CALLBACK (on_end_refresh),
 			  tree_view);
 
-	g_signal_connect (model, 
+	g_signal_connect (model,
 			  "unload",
-			  G_CALLBACK (on_unload), 
+			  G_CALLBACK (on_unload),
 			  tree_view);
 
-	g_signal_connect_after (model, 
+	g_signal_connect_after (model,
 			  "row-inserted",
-			  G_CALLBACK (on_row_inserted), 
+			  G_CALLBACK (on_row_inserted),
 			  tree_view);
 }
 
 static void
-set_restore_expand_state (GeditFileBrowserView * view,
-			  gboolean state)
+set_restore_expand_state (GeditFileBrowserView *view,
+			  gboolean              state)
 {
 	if (state == view->priv->restore_expand_state)
 		return;
@@ -770,7 +811,7 @@ set_restore_expand_state (GeditFileBrowserView * view,
 								  (GEqualFunc)g_file_equal,
 								  g_object_unref,
 								  NULL);
-		
+
 		if (view->priv->model && GEDIT_IS_FILE_BROWSER_STORE (view->priv->model))
 		{
 			fill_expand_state (view, NULL);
@@ -831,16 +872,16 @@ set_property (GObject      *object,
 }
 
 static void
-gedit_file_browser_view_class_init (GeditFileBrowserViewClass * klass)
+gedit_file_browser_view_class_init (GeditFileBrowserViewClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkTreeViewClass *tree_view_class = GTK_TREE_VIEW_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	
+
 	object_class->finalize = gedit_file_browser_view_finalize;
 	object_class->get_property = get_property;
 	object_class->set_property = set_property;
-	
+
 	/* Event handlers */
 	widget_class->motion_notify_event = motion_notify_event;
 	widget_class->enter_notify_event = enter_notify_event;
@@ -853,7 +894,7 @@ gedit_file_browser_view_class_init (GeditFileBrowserViewClass * klass)
 	/* Tree view handlers */
 	tree_view_class->row_expanded = row_expanded;
 	tree_view_class->row_collapsed = row_collapsed;
-	
+
 	/* Default handlers */
 	klass->directory_activated = directory_activated;
 
@@ -910,9 +951,11 @@ gedit_file_browser_view_class_init (GeditFileBrowserViewClass * klass)
 }
 
 static void
-cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
-	      GtkTreeModel * tree_model, GtkTreeIter * iter,
-	      GeditFileBrowserView * obj)
+cell_data_cb (GtkTreeViewColumn    *tree_column,
+	      GtkCellRenderer      *cell,
+	      GtkTreeModel         *tree_model,
+	      GtkTreeIter          *iter,
+	      GeditFileBrowserView *obj)
 {
 	GtkTreePath *path;
 	PangoUnderline underline = PANGO_UNDERLINE_NONE;
@@ -920,21 +963,19 @@ cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
 
 	path = gtk_tree_model_get_path (tree_model, iter);
 
-	if (obj->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
-		if (obj->priv->hover_path != NULL && 
-		    gtk_tree_path_compare (path, obj->priv->hover_path) == 0)
-			underline = PANGO_UNDERLINE_SINGLE;	
+	if (obj->priv->click_policy == GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE &&
+	    obj->priv->hover_path != NULL &&
+	    gtk_tree_path_compare (path, obj->priv->hover_path) == 0)
+	{
+		underline = PANGO_UNDERLINE_SINGLE;
 	}
 
-	if (GEDIT_IS_FILE_BROWSER_STORE (tree_model))
+	if (GEDIT_IS_FILE_BROWSER_STORE (tree_model) &&
+	    obj->priv->editable != NULL &&
+	    gtk_tree_row_reference_valid (obj->priv->editable))
 	{
-		if (obj->priv->editable != NULL && 
-		    gtk_tree_row_reference_valid (obj->priv->editable))
-		{
-			GtkTreePath *edpath = gtk_tree_row_reference_get_path (obj->priv->editable);
-			
-			editable = edpath && gtk_tree_path_compare (path, edpath) == 0;
-		}
+		GtkTreePath *edpath = gtk_tree_row_reference_get_path (obj->priv->editable);
+		editable = edpath && gtk_tree_path_compare (path, edpath) == 0;
 	}
 
 	gtk_tree_path_free (path);
@@ -942,7 +983,7 @@ cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
 }
 
 static void
-gedit_file_browser_view_init (GeditFileBrowserView * obj)
+gedit_file_browser_view_init (GeditFileBrowserView *obj)
 {
 	obj->priv = GEDIT_FILE_BROWSER_VIEW_GET_PRIVATE (obj);
 
@@ -982,8 +1023,9 @@ gedit_file_browser_view_init (GeditFileBrowserView * obj)
 }
 
 static gboolean
-bookmarks_separator_func (GtkTreeModel * model, GtkTreeIter * iter,
-			  gpointer user_data)
+bookmarks_separator_func (GtkTreeModel *model,
+			  GtkTreeIter  *iter,
+			  gpointer      user_data)
 {
 	guint flags;
 
@@ -1006,8 +1048,8 @@ gedit_file_browser_view_new (void)
 }
 
 void
-gedit_file_browser_view_set_model (GeditFileBrowserView * tree_view,
-				   GtkTreeModel * model)
+gedit_file_browser_view_set_model (GeditFileBrowserView *tree_view,
+				   GtkTreeModel         *model)
 {
 	GtkTreeSelection *selection;
 
@@ -1016,8 +1058,9 @@ gedit_file_browser_view_set_model (GeditFileBrowserView * tree_view,
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
 
-	if (GEDIT_IS_FILE_BOOKMARKS_STORE (model)) {
-		gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);		
+	if (GEDIT_IS_FILE_BOOKMARKS_STORE (model))
+	{
+		gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 		gtk_tree_view_set_row_separator_func (GTK_TREE_VIEW
 						      (tree_view),
 						      bookmarks_separator_func,
@@ -1029,7 +1072,9 @@ gedit_file_browser_view_set_model (GeditFileBrowserView * tree_view,
 							 (GtkTreeCellDataFunc)
 							 cell_data_cb,
 							 tree_view, NULL);
-	} else {
+	}
+	else
+	{
 		gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 		gtk_tree_view_set_row_separator_func (GTK_TREE_VIEW
 						      (tree_view), NULL,
@@ -1044,17 +1089,19 @@ gedit_file_browser_view_set_model (GeditFileBrowserView * tree_view,
 
 		if (tree_view->priv->restore_expand_state)
 			install_restore_signals (tree_view, model);
-				  
+
 	}
 
-	if (tree_view->priv->hover_path != NULL) {
+	if (tree_view->priv->hover_path != NULL)
+	{
 		gtk_tree_path_free (tree_view->priv->hover_path);
 		tree_view->priv->hover_path = NULL;
 	}
 
-	if (GEDIT_IS_FILE_BROWSER_STORE (tree_view->priv->model)) {
+	if (GEDIT_IS_FILE_BROWSER_STORE (tree_view->priv->model))
+	{
 		if (tree_view->priv->restore_expand_state)
-			uninstall_restore_signals (tree_view, 
+			uninstall_restore_signals (tree_view,
 						   tree_view->priv->model);
 	}
 
@@ -1063,8 +1110,8 @@ gedit_file_browser_view_set_model (GeditFileBrowserView * tree_view,
 }
 
 void
-gedit_file_browser_view_start_rename (GeditFileBrowserView * tree_view,
-				      GtkTreeIter * iter)
+gedit_file_browser_view_start_rename (GeditFileBrowserView *tree_view,
+				      GtkTreeIter          *iter)
 {
 	guint flags;
 	GtkTreeRowReference *rowref;
@@ -1087,40 +1134,38 @@ gedit_file_browser_view_start_rename (GeditFileBrowserView * tree_view,
 
 	/* Start editing */
 	gtk_widget_grab_focus (GTK_WIDGET (tree_view));
-	
+
 	if (gtk_tree_path_up (path))
 		gtk_tree_view_expand_to_path (GTK_TREE_VIEW (tree_view),
 					      path);
-	
+
 	gtk_tree_path_free (path);
 	tree_view->priv->editable = rowref;
 
 	gtk_tree_view_set_cursor (GTK_TREE_VIEW (tree_view),
 				  gtk_tree_row_reference_get_path (tree_view->priv->editable),
 				  tree_view->priv->column, TRUE);
-	
+
 	gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (tree_view),
 				      gtk_tree_row_reference_get_path (tree_view->priv->editable),
 				      tree_view->priv->column,
-				      TRUE,
-				      0.5,
-				      1);
+				      FALSE, 0.0, 0.0);
 }
 
 void
-gedit_file_browser_view_set_click_policy (GeditFileBrowserView *tree_view,
-					  GeditFileBrowserViewClickPolicy policy)
+gedit_file_browser_view_set_click_policy (GeditFileBrowserView            *tree_view,
+					  GeditFileBrowserViewClickPolicy  policy)
 {
 	g_return_if_fail (GEDIT_IS_FILE_BROWSER_VIEW (tree_view));
-	
+
 	set_click_policy_property (tree_view, policy);
-	
+
 	g_object_notify (G_OBJECT (tree_view), "click-policy");
 }
 
 void
-gedit_file_browser_view_set_restore_expand_state (GeditFileBrowserView * tree_view,
-						  gboolean restore_expand_state)
+gedit_file_browser_view_set_restore_expand_state (GeditFileBrowserView *tree_view,
+						  gboolean              restore_expand_state)
 {
 	g_return_if_fail (GEDIT_IS_FILE_BROWSER_VIEW (tree_view));
 
@@ -1130,55 +1175,58 @@ gedit_file_browser_view_set_restore_expand_state (GeditFileBrowserView * tree_vi
 
 /* Signal handlers */
 static void
-on_cell_edited (GtkCellRendererText * cell, gchar * path, gchar * new_text,
-		GeditFileBrowserView * tree_view)
+on_cell_edited (GtkCellRendererText  *cell,
+		gchar                *path,
+		gchar                *new_text,
+		GeditFileBrowserView *tree_view)
 {
-	GtkTreePath * treepath;
+	GtkTreePath *treepath;
 	GtkTreeIter iter;
 	gboolean ret;
-	GError * error = NULL;
-	
+	GError *error = NULL;
+
 	gtk_tree_row_reference_free (tree_view->priv->editable);
 	tree_view->priv->editable = NULL;
 
 	if (new_text == NULL || *new_text == '\0')
 		return;
-		
+
 	treepath = gtk_tree_path_new_from_string (path);
 	ret = gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_view->priv->model), &iter, treepath);
 	gtk_tree_path_free (treepath);
 
-	if (ret) {
+	if (ret)
+	{
 		if (gedit_file_browser_store_rename (GEDIT_FILE_BROWSER_STORE (tree_view->priv->model),
-		    &iter, new_text, &error)) {
+		    &iter, new_text, &error))
+		{
 			treepath = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_view->priv->model), &iter);
 			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (tree_view),
 						      treepath, NULL,
 						      FALSE, 0.0, 0.0);
 			gtk_tree_path_free (treepath);
 		}
-		else {
-			if (error) {
-				g_signal_emit (tree_view, signals[ERROR], 0,
-					       error->code, error->message);
-				g_error_free (error);
-			}
+		else if (error)
+		{
+			g_signal_emit (tree_view, signals[ERROR], 0,
+				       error->code, error->message);
+			g_error_free (error);
 		}
 	}
 }
 
-static void 
-on_begin_refresh (GeditFileBrowserStore * model, 
-		  GeditFileBrowserView * view)
+static void
+on_begin_refresh (GeditFileBrowserStore *model,
+		  GeditFileBrowserView  *view)
 {
 	/* Store the refresh state, so we can handle unloading of nodes while
 	   refreshing properly */
 	view->priv->is_refresh = TRUE;
 }
 
-static void 
-on_end_refresh (GeditFileBrowserStore * model, 
-		GeditFileBrowserView * view)
+static void
+on_end_refresh (GeditFileBrowserStore *model,
+		GeditFileBrowserView  *view)
 {
 	/* Store the refresh state, so we can handle unloading of nodes while
 	   refreshing properly */
@@ -1186,59 +1234,54 @@ on_end_refresh (GeditFileBrowserStore * model,
 }
 
 static void
-on_unload (GeditFileBrowserStore * model, 
-	   gchar const * uri,
-	   GeditFileBrowserView * view)
+on_unload (GeditFileBrowserStore *model,
+	   GFile                 *location,
+	   GeditFileBrowserView  *view)
 {
 	/* Don't remove the expand state if we are refreshing */
 	if (!view->priv->restore_expand_state || view->priv->is_refresh)
 		return;
-	
-	remove_expand_state (view, uri);
+
+	remove_expand_state (view, location);
 }
 
 static void
-restore_expand_state (GeditFileBrowserView * view,
-		      GeditFileBrowserStore * model,
-		      GtkTreeIter * iter)
+restore_expand_state (GeditFileBrowserView  *view,
+		      GeditFileBrowserStore *model,
+		      GtkTreeIter           *iter)
 {
-	gchar * uri;
-	GFile * file;
-	GtkTreePath * path;
+	GFile *location;
+	GtkTreePath *path;
 
-	gtk_tree_model_get (GTK_TREE_MODEL (model), 
-			    iter, 
-			    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, 
-			    &uri, 
+	gtk_tree_model_get (GTK_TREE_MODEL (model),
+			    iter,
+			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
+			    &location,
 			    -1);
 
-	if (!uri)
+	if (!location)
 		return;
 
-	file = g_file_new_for_uri (uri);
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), iter);
 
-	if (g_hash_table_lookup (view->priv->expand_state, file))
+	if (g_hash_table_lookup (view->priv->expand_state, location))
 	{
 		gtk_tree_view_expand_row (GTK_TREE_VIEW (view),
 					  path,
 					  FALSE);
 	}
-	
-	gtk_tree_path_free (path);
 
-	g_object_unref (file);	
-	g_free (uri);
+	gtk_tree_path_free (path);
 }
 
-static void 
-on_row_inserted (GeditFileBrowserStore * model, 
-		 GtkTreePath * path,
-		 GtkTreeIter * iter,
-		 GeditFileBrowserView * view)
+static void
+on_row_inserted (GeditFileBrowserStore *model,
+		 GtkTreePath           *path,
+		 GtkTreeIter           *iter,
+		 GeditFileBrowserView  *view)
 {
 	GtkTreeIter parent;
-	GtkTreePath * copy;
+	GtkTreePath *copy;
 
 	if (gtk_tree_model_iter_has_child (GTK_TREE_MODEL (model), iter))
 		restore_expand_state (view, model, iter);
@@ -1254,5 +1297,4 @@ on_row_inserted (GeditFileBrowserStore * model,
 
 	gtk_tree_path_free (copy);
 }
-				 
-// ex:ts=8:noet:
+/* ex:ts=8:noet: */
